Contributing
============

Welcome to the team!  By so much as reading the documentation or using the library you
are providing a valuable testing service to QTrio.  If you find anything amiss please do
submit a `GitHub issue <https://github.com/altendky/qtrio/issues>`__ to let us know.
If you are comfortable providing a
`pull request <https://github.com/altendky/qtrio/pulls>`__ to fix the issue, all the
better.

Since QTrio is early in its life, it is both more prone to problems and more flexible
about responding to them.  Community involvement is one of the key pieces to evolving
a powerful and usable library.  We each bring different perspectives and needs that
together expose the shortcomings and strengths of what we have made.
